-
-
Save tpruzina/a6317aad097374c70c3db7cfde9e308b to your computer and use it in GitHub Desktop.
Virtualbox-modules-6.0.0_beta2-Linux-4.20-rc5.patch
This file contains bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
diff -ru vbox2/vboxdrv/r0drv/linux/time-r0drv-linux.c vbox/vboxdrv/r0drv/linux/time-r0drv-linux.c | |
--- vbox2/vboxdrv/r0drv/linux/time-r0drv-linux.c 2017-10-17 18:23:45.000000000 +0200 | |
+++ vbox/vboxdrv/r0drv/linux/time-r0drv-linux.c 2018-11-25 18:09:53.726996529 +0100 | |
@@ -171,8 +171,8 @@ | |
{ | |
IPRT_LINUX_SAVE_EFL_AC(); | |
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 16) | |
- struct timespec Ts; | |
- ktime_get_real_ts(&Ts); | |
+ struct timespec64 Ts; | |
+ ktime_get_real_ts64(&Ts); | |
IPRT_LINUX_RESTORE_EFL_AC(); | |
return RTTimeSpecSetTimespec(pTime, &Ts); | |
Only in vbox/vboxdrv/r0drv/linux: time-r0drv-linux.c.orig | |
diff -ru vbox2/vboxnetadp/linux/VBoxNetAdp-linux.c vbox/vboxnetadp/linux/VBoxNetAdp-linux.c | |
--- vbox2/vboxnetadp/linux/VBoxNetAdp-linux.c 2017-10-28 17:21:15.000000000 +0200 | |
+++ vbox/vboxnetadp/linux/VBoxNetAdp-linux.c 2018-11-25 18:09:55.390996430 +0100 | |
@@ -129,7 +129,7 @@ | |
static const struct ethtool_ops gEthToolOpsVBoxNetAdp = | |
{ | |
.get_drvinfo = vboxNetAdpEthGetDrvinfo, | |
- .get_settings = vboxNetAdpEthGetSettings, | |
+ //.get_settings = vboxNetAdpEthGetSettings, | |
.get_link = ethtool_op_get_link, | |
}; | |
Only in vbox/vboxnetadp/linux: VBoxNetAdp-linux.c.orig | |
diff -ru vbox2/vboxdrv/include/iprt/time.h vbox/vboxdrv/include/iprt/time.h | |
--- vbox2/vboxdrv/include/iprt/time.h 2018-09-07 21:01:57.000000000 +0200 | |
+++ vbox/vboxdrv/include/iprt/time.h 2018-12-10 16:53:32.475735952 +0100 | |
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
/* PORTME: Add struct timespec guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
/** | |
@@ -402,7 +402,7 @@ | |
* @param pTime The time spec to interpret. | |
* @param pTimespec Where to store the time as POSIX timespec. | |
*/ | |
-DECLINLINE(struct timespec *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec *pTimespec) | |
+DECLINLINE(struct timespec64 *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec64 *pTimespec) | |
{ | |
int64_t i64 = RTTimeSpecGetNano(pTime); | |
int32_t i32Nano = (int32_t)(i64 % RT_NS_1SEC); | |
@@ -424,11 +424,11 @@ | |
* @param pTime The time spec to modify. | |
* @param pTimespec Pointer to the POSIX timespec struct with the new time. | |
*/ | |
-DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec *pTimespec) | |
+DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec64 *pTimespec) | |
{ | |
return RTTimeSpecAddNano(RTTimeSpecSetSeconds(pTime, pTimespec->tv_sec), pTimespec->tv_nsec); | |
} | |
-#endif /* various ways of detecting struct timespec */ | |
+#endif /* various ways of detecting struct timespec64 */ | |
Only in vbox/vboxdrv/include/iprt: time.h.orig | |
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
-/* PORTME: Add struct timespec guard macro here. */ | |
+/* PORTME: Add struct timespec64 guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
diff -ru vbox2/vboxnetadp/include/iprt/time.h vbox/vboxnetadp/include/iprt/time.h | |
--- vbox2/vboxnetadp/include/iprt/time.h 2018-09-07 21:01:57.000000000 +0200 | |
+++ vbox/vboxnetadp/include/iprt/time.h 2018-12-10 16:53:32.480735952 +0100 | |
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
/* PORTME: Add struct timespec guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
/** | |
@@ -402,7 +402,7 @@ | |
* @param pTime The time spec to interpret. | |
* @param pTimespec Where to store the time as POSIX timespec. | |
*/ | |
-DECLINLINE(struct timespec *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec *pTimespec) | |
+DECLINLINE(struct timespec64 *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec64 *pTimespec) | |
{ | |
int64_t i64 = RTTimeSpecGetNano(pTime); | |
int32_t i32Nano = (int32_t)(i64 % RT_NS_1SEC); | |
@@ -424,11 +424,11 @@ | |
* @param pTime The time spec to modify. | |
* @param pTimespec Pointer to the POSIX timespec struct with the new time. | |
*/ | |
-DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec *pTimespec) | |
+DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec64 *pTimespec) | |
{ | |
return RTTimeSpecAddNano(RTTimeSpecSetSeconds(pTime, pTimespec->tv_sec), pTimespec->tv_nsec); | |
} | |
-#endif /* various ways of detecting struct timespec */ | |
+#endif /* various ways of detecting struct timespec64 */ | |
Only in vbox/vboxnetadp/include/iprt: time.h.orig | |
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
-/* PORTME: Add struct timespec guard macro here. */ | |
+/* PORTME: Add struct timespec64 guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
diff -ru vbox2/vboxnetflt/include/iprt/time.h vbox/vboxnetflt/include/iprt/time.h | |
--- vbox2/vboxnetflt/include/iprt/time.h 2018-09-07 21:01:57.000000000 +0200 | |
+++ vbox/vboxnetflt/include/iprt/time.h 2018-12-10 16:53:32.485735952 +0100 | |
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
/* PORTME: Add struct timespec guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
/** | |
@@ -402,7 +402,7 @@ | |
* @param pTime The time spec to interpret. | |
* @param pTimespec Where to store the time as POSIX timespec. | |
*/ | |
-DECLINLINE(struct timespec *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec *pTimespec) | |
+DECLINLINE(struct timespec64 *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec64 *pTimespec) | |
{ | |
int64_t i64 = RTTimeSpecGetNano(pTime); | |
int32_t i32Nano = (int32_t)(i64 % RT_NS_1SEC); | |
@@ -424,11 +424,11 @@ | |
* @param pTime The time spec to modify. | |
* @param pTimespec Pointer to the POSIX timespec struct with the new time. | |
*/ | |
-DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec *pTimespec) | |
+DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec64 *pTimespec) | |
{ | |
return RTTimeSpecAddNano(RTTimeSpecSetSeconds(pTime, pTimespec->tv_sec), pTimespec->tv_nsec); | |
} | |
-#endif /* various ways of detecting struct timespec */ | |
+#endif /* various ways of detecting struct timespec64 */ | |
Only in vbox/vboxnetflt/include/iprt: time.h.orig | |
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
-/* PORTME: Add struct timespec guard macro here. */ | |
+/* PORTME: Add struct timespec64 guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
diff -ru vbox2/vboxpci/include/iprt/time.h vbox/vboxpci/include/iprt/time.h | |
--- vbox2/vboxpci/include/iprt/time.h 2018-09-07 21:01:57.000000000 +0200 | |
+++ vbox/vboxpci/include/iprt/time.h 2018-12-10 16:53:32.490735951 +0100 | |
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
/* PORTME: Add struct timespec guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
/** | |
@@ -402,7 +402,7 @@ | |
* @param pTime The time spec to interpret. | |
* @param pTimespec Where to store the time as POSIX timespec. | |
*/ | |
-DECLINLINE(struct timespec *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec *pTimespec) | |
+DECLINLINE(struct timespec64 *) RTTimeSpecGetTimespec(PCRTTIMESPEC pTime, struct timespec64 *pTimespec) | |
{ | |
int64_t i64 = RTTimeSpecGetNano(pTime); | |
int32_t i32Nano = (int32_t)(i64 % RT_NS_1SEC); | |
@@ -424,11 +424,11 @@ | |
* @param pTime The time spec to modify. | |
* @param pTimespec Pointer to the POSIX timespec struct with the new time. | |
*/ | |
-DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec *pTimespec) | |
+DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec(PRTTIMESPEC pTime, const struct timespec64 *pTimespec) | |
{ | |
return RTTimeSpecAddNano(RTTimeSpecSetSeconds(pTime, pTimespec->tv_sec), pTimespec->tv_nsec); | |
} | |
-#endif /* various ways of detecting struct timespec */ | |
+#endif /* various ways of detecting struct timespec64 */ | |
Sign up for free
to join this conversation on GitHub.
Already have an account?
@@ -392,7 +392,7 @@ | |
#endif /* various ways of detecting struct timeval */ | |
-/* PORTME: Add struct timespec guard macro here. */ | |
+/* PORTME: Add struct timespec64 guard macro here. */ | |
#if defined(RTTIME_INCL_TIMESPEC) || defined(_STRUCT_TIMESPEC) || defined(_SYS__TIMESPEC_H_) || defined(TIMEVAL_TO_TIMESPEC) || defined(_TIMESPEC) \ | |
|| (defined(RT_OS_NETBSD) && defined(_SYS_TIME_H_)) | |
Sign in to comment
cd vbox-modules-6.0.0_beta2
patch -p1 <<< $(curl https://gist.githubusercontent.com/tpruzina/a6317aad097374c70c3db7cfde9e308b/raw/6ad28bf4b2f7429a1d5cd470ec2323fc45aa2cd0/6464)